==> Hot3nCoder-1.0.1.tar.gz: Hot3nCoder-1.0.1/README.md <==
# Hot3nCoder
A tool to encode your .cpp file with whatever you want

## How to use
- open your terminal
- type "pip install HotCoder" in your terminal
- type "hot3ncoder -i \<YourCppFilePath\> -s \<Symbols you want\n>
  - notice that symbols should split with " "
- the Encoded file will generate in the same directory of your cpp file

### Example
Hot3nCoder -i "C:/ex.cpp" -s "🥵 😉 Hello"

#### ex.cpp  
> #include<bits/stdc++.h>  
> using namespace std;  
>  
> int main(){  
> 　　string str = "test";  
> 　　cout<<str<<'\n';  
> 　　for(int i=0;i<10;i++){  
> 　　　　cout<<i<<endl;  
> 　　}  
>  
> 　　return 0;  
> }

#### Hot3nCoder.cpp
> #include<bits/stdc++.h>  
> #define AAAHelloHello {    
> #define AA😉HelloHello namespace  
> #define AA🥵Hello ;  
> #define A😉AHelloHelloHello string　　
> #define A😉😉HelloHello endl  
> #define A😉🥵Hello main  
> #define A🥵AHelloHello ++   
> #define A🥵😉Hello 0   
> #define A🥵🥵HelloHello int   
> #define 😉AAHello i   
> #define 😉A😉 '\n'   
> #define 😉A🥵HelloHelloHello )  
> #define 😉😉AHelloHelloHello cout   
> #define 😉😉😉Hello using   
> #define 😉😉🥵HelloHello <  
> #define 😉🥵AHelloHello str   
> #define 😉🥵😉Hello return   
> #define 😉🥵🥵Hello "test"  
> #define 🥵AAHelloHello 10   
> #define 🥵A😉HelloHello std   
> #define 🥵A🥵 for   
> #define 🥵😉AHelloHello (  
> #define 🥵😉😉 =   
> #define 🥵😉🥵HelloHelloHello }   
> #define 🥵🥵AHello <<  
> 😉😉😉Hello AA😉HelloHello 🥵A😉HelloHello AA🥵Hello    
>     
>  A🥵🥵HelloHello A😉🥵Hello 🥵😉AHelloHello  😉A🥵HelloHelloHello  AAAHelloHello    
>      A😉AHelloHelloHello 😉🥵AHelloHello  🥵😉😉  😉🥵🥵Hello AA🥵Hello    
>      😉😉AHelloHelloHello 🥵🥵AHello 😉🥵AHelloHello 🥵🥵AHello 😉A😉 AA🥵Hello    
>      🥵A🥵 🥵😉AHelloHello A🥵🥵HelloHello 😉AAHello 🥵😉😉 A🥵😉Hello AA🥵Hello 😉AAHello 😉😉🥵HelloHello 🥵AAHelloHello AA🥵Hello 😉AAHello A🥵AHelloHello  😉A🥵HelloHelloHello  AAAHelloHello    
>          😉😉AHelloHelloHello 🥵🥵AHello 😉AAHello 🥵🥵AHello A😉😉HelloHello AA🥵Hello    
>       🥵😉🥵HelloHelloHello    
>     
>      😉🥵😉Hello A🥵😉Hello AA🥵Hello    
>   🥵😉🥵HelloHelloHello    
>  
>  /*Created by Jasoff*/  

#  Issue
- Some terminal doesn't support emoji encoding, using one that would show emoji will avoid an error.

==> Hot3nCoder-1.0.2.tar.gz: Hot3nCoder-1.0.2/README.md <==
# Hot3nCoder
A tool to encode your .cpp file with whatever you want

## How to use
- open your terminal
- type "pip install Hot3nCoder" in your terminal
- type "Hot3nCoder -i \<YourCppFilePath\> -s \<Symbols you want\n>
  - notice that symbols should split with " "
- the Encoded file will generate in the same directory of your cpp file

### Example
Hot3nCoder -i "C:/ex.cpp" -s "🥵 😉 Hello"

#### ex.cpp  
> #include<bits/stdc++.h>  
> using namespace std;  
>  
> int main(){  
> 　　string str = "test";  
> 　　cout<<str<<'\n';  
> 　　for(int i=0;i<10;i++){  
> 　　　　cout<<i<<endl;  
> 　　}  
>  
> 　　return 0;  
> }

#### Hot3nCoder.cpp
> #include<bits/stdc++.h>  
> #define AAAHelloHello {    
> #define AA😉HelloHello namespace  
> #define AA🥵Hello ;  
> #define A😉AHelloHelloHello string　　
> #define A😉😉HelloHello endl  
> #define A😉🥵Hello main  
> #define A🥵AHelloHello ++   
> #define A🥵😉Hello 0   
> #define A🥵🥵HelloHello int   
> #define 😉AAHello i   
> #define 😉A😉 '\n'   
> #define 😉A🥵HelloHelloHello )  
> #define 😉😉AHelloHelloHello cout   
> #define 😉😉😉Hello using   
> #define 😉😉🥵HelloHello <  
> #define 😉🥵AHelloHello str   
> #define 😉🥵😉Hello return   
> #define 😉🥵🥵Hello "test"  
> #define 🥵AAHelloHello 10   
> #define 🥵A😉HelloHello std   
> #define 🥵A🥵 for   
> #define 🥵😉AHelloHello (  
> #define 🥵😉😉 =   
> #define 🥵😉🥵HelloHelloHello }   
> #define 🥵🥵AHello <<  
> 😉😉😉Hello AA😉HelloHello 🥵A😉HelloHello AA🥵Hello    
>     
>  A🥵🥵HelloHello A😉🥵Hello 🥵😉AHelloHello  😉A🥵HelloHelloHello  AAAHelloHello    
>      A😉AHelloHelloHello 😉🥵AHelloHello  🥵😉😉  😉🥵🥵Hello AA🥵Hello    
>      😉😉AHelloHelloHello 🥵🥵AHello 😉🥵AHelloHello 🥵🥵AHello 😉A😉 AA🥵Hello    
>      🥵A🥵 🥵😉AHelloHello A🥵🥵HelloHello 😉AAHello 🥵😉😉 A🥵😉Hello AA🥵Hello 😉AAHello 😉😉🥵HelloHello 🥵AAHelloHello AA🥵Hello 😉AAHello A🥵AHelloHello  😉A🥵HelloHelloHello  AAAHelloHello    
>          😉😉AHelloHelloHello 🥵🥵AHello 😉AAHello 🥵🥵AHello A😉😉HelloHello AA🥵Hello    
>       🥵😉🥵HelloHelloHello    
>     
>      😉🥵😉Hello A🥵😉Hello AA🥵Hello    
>   🥵😉🥵HelloHelloHello    
>  
>  /*Created by Jasoff*/  

#  Issue
- Some terminal doesn't support emoji encoding, using one that would show emoji will avoid an error.
